@@ -1,8 +1,8 @@
 /* BEGIN_COMMON_COPYRIGHT_HEADER
  * (c)LGPL2+
  *
- * LXDE-Qt - a lightweight, Qt based, desktop toolset
- * http://razor-qt.org
+ * LXQt - a lightweight, Qt based, desktop toolset
+ * https://lxqt.org
  *
  * Copyright: 2011-2012 Razor team
  * Authors:
@@ -52,11 +52,11 @@ PolicykitAgentGUI::PolicykitAgentGUI(const QString &actionId,
 
     const uid_t current_uid = getuid();
     int current_user_index = -1;
-    foreach (PolkitQt1::Identity identity, identities)
+    for (const PolkitQt1::Identity& identity : identities)
     {
         const int i = identityComboBox->count(); // index of the added item
         identityComboBox->addItem(identity.toString());
-        PolkitQt1::UnixUserIdentity const * const u_id = static_cast<PolkitQt1::UnixUserIdentity *>(&identity);
+        PolkitQt1::UnixUserIdentity const * const u_id = static_cast<const PolkitQt1::UnixUserIdentity *>(&identity);
         if (u_id != nullptr && u_id->uid() == current_uid)
             current_user_index = i;
     }
